==> hermes-3.0.0.13.tar.gz: hermes-3.0.0.13/app/controllers/hermes/api/dmo/housing_request_entity_form_levels_controller.rb <==
# frozen_string_literal: true

class Hermes::Api::Dmo::HousingRequestEntityFormLevelsController < Hermes::Api::Dmo::ApplicationController
  before_action :set_entity, only: %i[show index create]
  before_action :set_entity_administrator, only: %i[update destroy]
  before_action :set_form_level, only: %i[show update destroy]

  VALID_OPERATORS = %w[$in $nin $ne $gt $gte $lt $lte $eq $regex $all]
  ACCEPTABLE_PARAMS = %w[
    consent_fields
    description
    level
    delegation
    entity_id
    created_at
    updated_at
  ]
  MUTATE_PARAMS = %i[
    consent_fields
    description
    level
    delegation
    entity_id
  ]
  mutate_params_only *MUTATE_PARAMS

  def index
    acceptable_params *ACCEPTABLE_PARAMS
    valid_operators *VALID_OPERATORS

    form_levels = @entity.form_levels.where(build_query(Hermes::HousingRequestEntityFormLevel)).order(order_params)
    paginate(
      form_levels,
      each_serializer: Hermes::HousingRequestEntityFormLevelSerializer
    )
  end

  def show
    return render_json_error(:unauthorized, :not_readers) unless @entity.readable_by?(@user)

    super
  end

  def create
    return render_json_error(:unauthorized, :not_entreprise) unless current_user_roles.include?('entreprise') || current_user_roles.include?('superadministrateur') || current_user_roles.include?('collaborateur entreprise')

    user_id = @user.id
    @instance = @entity.form_levels.build(mutate_valid_params.merge(user_id: user_id))
    return respond_with_errors(@instance) unless @instance.save

    render(jsonapi: @instance, serializer: Hermes::HousingRequestEntityFormLevelSerializer, status: :created)
  end

  private

  def set_form_level
    @instance = @entity.form_levels.find_by(id: params[:id])
  end

  def set_entity
    @entity = Hermes::Entity.find_by(id: params[:entity_id])
    return render_json_error(:not_found, :instance_not_found) unless @entity
  end
  
  def set_entity_administrator
    @entity = Hermes::Entity.find_by(id: params[:entity_id])
    return render_json_error(:not_found, :instance_not_found) unless @entity
    ur = Hermes::UserRight.find_by(user_id: current_user.id, entity_id: @entity.id, right: 'administrator')
    return render_json_error(:unauthorized, :not_administrator_right_on_entity) unless ur || current_user_roles.include?('superadministrateur') 
  end

  def user_can_destroy?
    # method set_entity_administrator already check current_user_right
    true
  end
end

==> hermes-5.5.0.11.tar.gz: hermes-5.5.0.11/app/controllers/hermes/api/dmo/housing_request_entity_form_levels_controller.rb <==
# frozen_string_literal: true

class Hermes::Api::Dmo::HousingRequestEntityFormLevelsController < Hermes::Api::Dmo::ApplicationController
  before_action :set_entity_administrator, only: %i[update destroy]

  VALID_OPERATORS = %w[$in $nin $ne $gt $gte $lt $lte $eq $regex $all]
  ACCEPTABLE_PARAMS = %w[
    consent_fields
    description
    level
    delegation
    entity_id
    created_at
    updated_at
  ]
  MUTATE_PARAMS = %i[
    consent_fields
    description
    level
    delegation
    entity_id
  ]
  mutate_params_only *MUTATE_PARAMS

  def index
    acceptable_params *ACCEPTABLE_PARAMS
    valid_operators *VALID_OPERATORS

    return render_json_error(:unprocessable_entity, :missing_entity_siret) unless params[:entity_siret]

    @entity = Hermes::Entity.find_by(siret: params[:entity_siret])
    return render_json_error(:not_found, :instance_not_found) unless @entity

    form_levels = @entity.form_levels.where(build_query(Hermes::HousingRequestEntityFormLevel)).order(order_params)
    paginate(
      form_levels,
      each_serializer: Hermes::HousingRequestEntityFormLevelSerializer
    )
  end

  def show
    return render_json_error(:not_found, :object_not_found) unless @instance
    return render_json_error(:unauthorized, :not_readers) unless @instance.entity&.readable_by?(@user)

    super
  end

  def create
    return render_json_error(:unauthorized, :not_entreprise) unless current_user_roles.include?('entreprise') || current_user_roles.include?('superadministrateur') || current_user_roles.include?('collaborateur entreprise')

    super
  end

  private

  def set_instance
    @instance = @model.find_by(id: params[:id]) if params[:id]
  end

  def set_entity_administrator
    return render_json_error(:not_found, :object_not_found) unless @instance
    ur = Hermes::UserRight.find_by(user_id: current_user.id, entity_id: @instance.entity_id, right: 'administrator')
    return render_json_error(:unauthorized, :not_administrator_right_on_entity) unless ur || current_user_roles.include?('superadministrateur') 
  end

  def user_can_destroy?
    # method set_entity_administrator already check current_user_right
    true
  end
end
